pyjabber.plugins.xep\_0060 package
==================================

Submodules
----------

pyjabber.plugins.xep\_0060.enum module
--------------------------------------

.. automodule:: pyjabber.plugins.xep_0060.enum
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.plugins.xep\_0060.error module
---------------------------------------

.. automodule:: pyjabber.plugins.xep_0060.error
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.plugins.xep\_0060.xep\_0060 module
-------------------------------------------

.. automodule:: pyjabber.plugins.xep_0060.xep_0060
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.plugins.xep_0060
   :members:
   :undoc-members:
   :show-inheritance:
